#!/bin/sh
#  Copyright (C) 2000-2007 SWsoft. All rights reserved.
#  Copyright (C) 2006-2007 Dmitry V. Levin <ldv@altlinux.org>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
#
#
# This script runnning on HN and perform next postinstall tasks:
# 1. Randomizes crontab for given VE so all crontab tasks
#  of all VEs will not start at the same time.
# 2. Disables root password if it is empty.
#

randcrontab()
{
	file="$VE_ROOT/etc/crontab"

	[ -f "$file" ] || return 0

	cp -fp "$file" "$file.$$" &&
		awk '
BEGIN { srand(); }
{
	if ($0 ~ /^[ \t]*#/ || $0 ~ /^[ \t]+*$/) {
		print $0;
        	next;
	}
	if ((n = split($0, ar, /[ \t]/)) < 7) {
		print $0;
		next;
	}
	# min
	if (ar[1] ~ /^[0-9]+$/) {
		ar[1] = int(rand() * 59);
	} else if (ar[1] ~/^-\*\/[0-9]+$/) {
		r = int(rand() * 40) + 15;
		ar[1] = "-*/" r;
	}
	# hour
	if (ar[2] ~ /^[0-9]+$/) {
		ar[2] = int(rand() * 6);
	}
	# day
	if (ar[3] ~ /^[0-9]+$/) {
		ar[3] = int(rand() * 31) + 1;
	}
	line = ar[1];
	for (i = 2; i <= n; i++) {
		line = line " "  ar[i];
	}
	print line;
}
' < "$file" > "$file.$$" && mv -f "$file.$$" "$file"
	rm -f "$file.$$" 2>/dev/null
}

disableroot()
{
	file="$VE_ROOT/etc/passwd"

	[ -f "$file" ] &&
		grep -qs '^root::' "$file" ||
		return 0

	sed -i 's/^root::/root:!!:/g' "$file"
}

fixinittab()
{
	file="$VE_ROOT/etc/inittab"

	[ -f "$file" ] &&
		grep -qs '^[0-9].*mingetty.*tty' "$file" ||
		return 0

	sed -i 's|^[0-9].*mingetty.*tty|#&|' "$file"
}

fixsyslog()
{
	file="$VE_ROOT/etc/syslog.conf"

	[ -f "$file" ] &&
		grep -qs '^[^#[:space:]]\+[[:space:]]\+/dev/tty' "$file" ||
		return 0

	sed -i 's|^[^#[:space:]]\+[[:space:]]\+/dev/tty|#&|' "$file"
}

fixfstab()
{
	file="$VE_ROOT/etc/fstab"

	[ -f "$file" ] &&
		grep -qs '^tmpfs[[:space:]]\+/tmp[[:space:]]\+tmpfs[[:space:]]\+nosuid[[:space:]]\+0[[:space:]]\+0[[:space:]]*$' "$file" ||
		return 0

	sed -i 's|^tmpfs[[:space:]]\+/tmp[[:space:]]\+tmpfs[[:space:]]\+nosuid[[:space:]]\+0[[:space:]]\+0[[:space:]]*$|#&|' "$file"
}

copy_localtime()
{
	local f=/etc/localtime
	if [ -s "$f" ]; then
		rm -f -- "$VE_ROOT$f" &&
			install -pm644 -- "$f" "$VE_ROOT$f"
	fi
}

[ -n "$VE_ROOT" ] || exit 1
randcrontab
disableroot
fixinittab
fixsyslog
fixfstab
copy_localtime
if [ -d /etc/hooks/post_create.d ] &&
   type run-parts >/dev/null 2>&1; then
	run-parts /etc/hooks/post_create.d
fi

exit 0
